@@ -8,7 +8,7 @@ use Mojo::Base -base;
 use Mojo::Loader qw(data_section);
 use Text::Xslate ();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 $VERSION = eval $VERSION;
 
 has 'xslate';
@@ -56,16 +56,34 @@ sub _render {
         || $renderer->template_name($options);
     my %params = (%{$c->stash}, c => $c);
 
+    my $orig_err = $@;
+    my $xslate_err;
+
     local $@;
     if (defined(my $inline = $options->{inline})) {
-        $$output = $self->xslate->render_string($inline, \%params);
+        eval {
+            local $SIG{__DIE__} = sub { $xslate_err = shift };
+            $$output = $self->xslate->render_string($inline, \%params);
+        };
     }
     else {
-        $$output = $self->xslate->render($name, \%params);
+        eval {
+            local $SIG{__DIE__} = sub { $xslate_err = shift };
+            $$output = $self->xslate->render($name, \%params);
+        };
     }
-    die $@ if $@;
+    $@ = $xslate_err if $xslate_err;
 
-    return 1;
+    if ($@) {
+        $$output = undef;
+        if (    ( index( $@, 'Text::Xslate: LoadError: Cannot find \'exception.' ) < 0 )
+             && ( index( $@, 'Text::Xslate: LoadError: Cannot find \'not_found.' ) < 0 )
+        ) {
+            die $@ unless $orig_err;
+        }
+    }
+
+    return;
 }
 
 
@@ -167,7 +185,7 @@ L<http://search.cpan.org/dist/MojoX-Renderer-Xslate/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2015 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2010-2016 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
@@ -175,5 +193,6 @@ the same terms as Perl itself.
 =head1 AUTHOR
 
 gray, <gray at cpan.org>
+hjansen, <hjansen at cpan.org>
 
 =cut
